ChatModel class

Available extensions
Annotations

Constructors

ChatModel({required String id, String? displayName, required ChatModelCost cost, required ChatModelCapabilities capabilities, bool isDeprecated = false})
const
ChatModel.basic(String id)
const
ChatModel.safe(String id)
const

Properties

capabilities ChatModelCapabilities
final
cost ChatModelCost
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDeprecated bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to → _a

Available on _e, provided by the $ChatModel extension

no setter

Methods

connect(ChatConnector connector) ConnectedChatModel
copyWith({_7? id, _7? displayName, _19 deleteDisplayName = _F, _w? cost, _v? capabilities, _19? isDeprecated, _19 resetIsDeprecated = _F}) → _e

Available on _e, provided by the $ChatModel extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _e, provided by the $ChatModel extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited