ChatResult class
- Available extensions
- Annotations
Constructors
-
ChatResult({required AgentMessage message, required ARational realCost, ChatFinishReason finishReason = ChatFinishReason.unspecified, Map<
String, dynamic> metadata = const {}, ChatUsage usage = const ChatUsage()}) -
const
Properties
- finishReason → ChatFinishReason
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → AgentMessage
-
final
-
metadata
→ Map<
String, dynamic> -
final
- realCost → ARational
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → _a
-
Available on _g, provided by the $ChatResult extension
no setter - usage → ChatUsage
-
final
Methods
-
copyWith(
{_o? message, _f? realCost, _1g? finishReason, _19 resetFinishReason = _F, _1h? metadata, _19 resetMetadata = _F, _h? usage, _19 resetUsage = _F}) → _g -
Available on _g, provided by the $ChatResult extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _g, provided by the $ChatResult extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited