Message class
- Implementers
- Available extensions
- Annotations
Constructors
- Message({required Content content})
-
const
- Message.agent(String content)
-
factory
- Message.system(String content)
-
factory
- Message.tool(String content, String toolCallId)
-
factory
- Message.user(String content)
-
factory
Properties
- content → Content
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → _a
-
Available on _n, provided by the $Message extension
no setter - toLangChain → ChatMessage
-
Available on Message, provided by the XChatMessage2LC extension
no setter
Methods
-
copyWith(
{_i? content}) → _n -
Available on _n, provided by the $Message extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _n, provided by the $Message extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited