NagaModelsListResponse class

Available extensions
Annotations

Constructors

NagaModelsListResponse({List<NagaModel> data = const []})
const

Properties

data List<NagaModel>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to → _a

Available on _x, provided by the $NagaModelsListResponse extension

no setter

Methods

copyWith({_27? data, _19 resetData = _F, _27? appendData, _27? removeData}) → _x

Available on _x, provided by the $NagaModelsListResponse extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _x, provided by the $NagaModelsListResponse extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited