OpenRouterArchitecture class

Available extensions
Annotations

Constructors

OpenRouterArchitecture({required String modality, List<String> input_modalities = const [], List<String> output_modalities = const [], required String tokenizer})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input_modalities List<String>
final
modality String
final
output_modalities List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to → _a

Available on _13, provided by the $OpenRouterArchitecture extension

no setter
tokenizer String
final

Methods

copyWith({_7? modality, _6? input_modalities, _19 resetInput_modalities = _F, _6? appendInput_modalities, _6? removeInput_modalities, _6? output_modalities, _19 resetOutput_modalities = _F, _6? appendOutput_modalities, _6? removeOutput_modalities, _7? tokenizer}) → _13

Available on _13, provided by the $OpenRouterArchitecture extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _13, provided by the $OpenRouterArchitecture extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited