OpenRouterModel class

Available extensions
Annotations

Constructors

OpenRouterModel({required String id, required String canonical_slug, required String name, required int created, required int context_length, required OpenRouterArchitecture architecture, List<String> supported_parameters = const [], OpenRouterPricing pricing = const OpenRouterPricing()})
const

Properties

architecture OpenRouterArchitecture
final
canonical_slug String
final
context_length int
final
created int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
pricing OpenRouterPricing
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supported_parameters List<String>
final
to → _a

Available on _12, provided by the $OpenRouterModel extension

no setter
toChatModel ChatModel
no setter

Methods

copyWith({_7? id, _7? canonical_slug, _7? name, _9? created, _9? deltaCreated, _9? context_length, _9? deltaContext_length, _13? architecture, _6? supported_parameters, _19 resetSupported_parameters = _F, _6? appendSupported_parameters, _6? removeSupported_parameters, _14? pricing, _19 resetPricing = _F}) → _12

Available on _12, provided by the $OpenRouterModel extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _12, provided by the $OpenRouterModel extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited