OpenRouterCreateApiKeyRequest class

Constructors

OpenRouterCreateApiKeyRequest({required String name, String? creatorUserId, DateTime? expiresAt, bool? includeByokInLimit, double? limit, OpenRouterApiKeyLimitReset? limitReset})
const
OpenRouterCreateApiKeyRequest.oneTimeUseBurn({required String name, required double limit, String? creatorUserId, DateTime? expiresAt, bool? includeByokInLimit})
factory
OpenRouterCreateApiKeyRequest.recurring({required String name, required double limit, required OpenRouterApiKeyLimitReset limitReset, String? creatorUserId, DateTime? expiresAt, bool? includeByokInLimit})
factory
OpenRouterCreateApiKeyRequest.unlimited({required String name, String? creatorUserId, DateTime? expiresAt, bool? includeByokInLimit})
factory

Properties

creatorUserId String?
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
includeByokInLimit bool?
final
limit double?
final
limitReset OpenRouterApiKeyLimitReset?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited