TextContent class
- Inheritance
- Available extensions
- Annotations
Constructors
- TextContent({String text = ""})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- to → _a
-
Available on _i, provided by the $Content extension
no setter - to → _a
-
Available on _m, provided by the $TextContent extension
no setter - toLangChain → ChatMessageContent
-
Available on Content, provided by the XChatMessageContent2LC extension
no setter
Methods
-
and(
Content other) → Content -
inherited
-
copyWith(
{_7? text, _19 resetText = _F}) → _m -
Available on _m, provided by the $TextContent extension
-
explode(
) → Iterable< Content> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _i, provided by the $Content extension
-
toMap(
) → _5 -
Available on _m, provided by the $TextContent extension
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited