UserMessage class
- Inheritance
- Available extensions
- Annotations
Constructors
- UserMessage({required Content content})
-
const
Properties
- content → Content
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → _a
-
Available on _n, provided by the $Message extension
no setter - to → _a
-
Available on _r, provided by the $UserMessage extension
no setter - toLangChain → ChatMessage
-
Available on Message, provided by the XChatMessage2LC extension
no setter
Methods
-
copyWith(
{_i? content}) → _n -
Available on _n, provided by the $Message extension
-
copyWith(
{_i? content}) → _r -
Available on _r, provided by the $UserMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _n, provided by the $Message extension
-
toMap(
) → _5 -
Available on _r, provided by the $UserMessage extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited