ChatModelCost class
- Available extensions
- Annotations
Constructors
- ChatModelCost({required double input, required double output})
-
const
- ChatModelCost.free()
-
factory
- ChatModelCost.io(double input, double output)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → double
-
final
- output → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → _a
-
Available on _w, provided by the $ChatModelCost extension
no setter
Methods
-
copyWith(
{_25? input, _25? deltaInput, _25? output, _25? deltaOutput}) → _w -
Available on _w, provided by the $ChatModelCost extension
-
getEstimatedCost(
int inputTokens, int outputTokens) → double -
getRealCost(
int inputTokens, int outputTokens) → Rational -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _w, provided by the $ChatModelCost extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited